@@ -73,6 +73,11 @@ enum
 };
 
 /* generic templates */
+static GstStaticPadTemplate spider_sink_factory =
+GST_STATIC_PAD_TEMPLATE ("sink",
+    GST_PAD_SINK,
+    GST_PAD_ALWAYS,
+    GST_STATIC_CAPS_ANY);
 static GstStaticPadTemplate spider_src_factory =
 GST_STATIC_PAD_TEMPLATE ("src_%d",
     GST_PAD_SRC,
@@ -94,7 +99,8 @@ static void gst_spider_get_property (GObject * object, guint prop_id,
 
 /* link functions */
 static GstSpiderConnection *gst_spider_link_new (GstSpiderIdentity * src);
-static void gst_spider_link_destroy (GstSpiderConnection * conn);
+
+/* static void gst_spider_link_destroy (GstSpiderConnection * conn); */
 static void gst_spider_link_reset (GstSpiderConnection * conn, GstElement * to);
 static void gst_spider_link_add (GstSpiderConnection * conn,
     GstElement * element);
@@ -170,6 +176,8 @@ gst_spider_class_init (GstSpiderClass * klass)
   gobject_class->get_property = gst_spider_get_property;
   gobject_class->dispose = gst_spider_dispose;
 
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&spider_sink_factory));
   gst_element_class_add_pad_template (gstelement_class,
       gst_static_pad_template_get (&spider_src_factory));
   gst_element_class_set_details (gstelement_class, &gst_spider_details);
@@ -183,6 +191,7 @@ gst_spider_init (GstSpider * spider)
   /* use only elements which have sources and sinks and where the sinks have caps */
   /* FIXME: How do we handle factories that are added after the spider was constructed? */
   GList *list = gst_registry_pool_feature_list (GST_TYPE_ELEMENT_FACTORY);
+
   spider->factories = gst_autoplug_factories_filters_with_sink_caps (list);
   g_list_free (list);
 
@@ -205,9 +214,9 @@ gst_spider_dispose (GObject * object)
   g_list_free (spider->factories);
   spider->factories = NULL;
 
-  for (list = spider->links; list; list = list->next)
-  {
+  for (list = spider->links; list; list = list->next) {
     GstSpiderConnection *conn = list->data;
+
     g_list_free (conn->path);
     g_free (conn);
   }
@@ -343,6 +352,8 @@ gst_spider_link_new (GstSpiderIdentity * src)
 
   return conn;
 }
+
+#if 0
 static void
 gst_spider_link_destroy (GstSpiderConnection * conn)
 {
@@ -352,6 +363,8 @@ gst_spider_link_destroy (GstSpiderConnection * conn)
   gst_spider_link_reset (conn, (GstElement *) spider->sink_ident);
   g_free (conn);
 }
+#endif
+
 static void
 gst_spider_link_reset (GstSpiderConnection * conn, GstElement * to)
 {
@@ -511,6 +524,7 @@ gst_spider_identity_plug (GstSpiderIdentity * ident)
   ident->plugged = TRUE;
 }
 
+#if 0
 void
 gst_spider_identity_unplug (GstSpiderIdentity * ident)
 {
@@ -521,12 +535,15 @@ gst_spider_identity_unplug (GstSpiderIdentity * ident)
     GstSpiderConnection *conn = list->data;
 
     if (conn->src == ident) {
-      g_list_delete_link (spider->links, list);
+      spider->links = g_list_delete_link (spider->links, list);
       gst_spider_link_destroy (conn);
+      /* assuming we have found the one and only list item */
+      break;
     }
   }
   ident->plugged = FALSE;
 }
+#endif
 
 /* links src to sink using the elementfactories in plugpath
  * plugpath will be removed afterwards */
@@ -553,7 +570,7 @@ gst_spider_create_and_plug (GstSpiderConnection * conn, GList * plugpath)
 
       endelements = g_list_prepend (endelements, element);
       templist = g_list_previous (templist);
-      g_list_delete_link (cur, cur);
+      cur = g_list_delete_link (cur, cur);
     }
   }
 
@@ -741,8 +758,7 @@ plugin_init (GstPlugin * plugin)
   GST_DEBUG_CATEGORY_INIT (gst_spider_debug, "spider", 0,
       "spider autoplugging element");
 
-  if (!gst_element_register (plugin, "spider", GST_RANK_SECONDARY,
-          GST_TYPE_SPIDER))
+  if (!gst_element_register (plugin, "spider", GST_RANK_NONE, GST_TYPE_SPIDER))
     return FALSE;
   if (!gst_element_register (plugin, "spideridentity", GST_RANK_NONE,
           GST_TYPE_SPIDER_IDENTITY))
